@@ -1,3 +1,4 @@
-from .graphite import Statsd
+from .statsd_ import Statsd
 from .default import Default
 from .slack import SlackTelemeter
+from .statsd_ import Statsd
